@@ -379,33 +379,33 @@ hangul_jamo_to_cjamo(ucschar c)
 	0x0000,     /* 0x11a5 */
 	0x0000,     /* 0x11a6 */
 	0x0000,     /* 0x11a7 */
-	0x0000,     /* 0x11a8 */
-	0x0000,     /* 0x11a9 */
-	0x3133,     /* 0x11aa */
-	0x0000,     /* 0x11ab */
-	0x3135,     /* 0x11ac */
-	0x3136,     /* 0x11ad */
-	0x0000,     /* 0x11ae */
-	0x0000,     /* 0x11af */
-	0x313a,     /* 0x11b0 */
-	0x313b,     /* 0x11b1 */
-	0x313c,     /* 0x11b2 */
-	0x313d,     /* 0x11b3 */
-	0x313e,     /* 0x11b4 */
-	0x313f,     /* 0x11b5 */
-	0x0000,     /* 0x11b6 */
-	0x0000,     /* 0x11b7 */
-	0x0000,     /* 0x11b8 */
-	0x0000,     /* 0x11b9 */
-	0x0000,     /* 0x11ba */
-	0x0000,     /* 0x11bb */
-	0x0000,     /* 0x11bc */
-	0x0000,     /* 0x11bd */
-	0x0000,     /* 0x11be */
-	0x0000,     /* 0x11bf */
-	0x0000,     /* 0x11c0 */
-	0x0000,     /* 0x11c1 */
-	0x0000,     /* 0x11c2 */
+	0x3131,	    /* 0x11a8 */
+	0x3132,	    /* 0x11a9 */
+	0x3133,	    /* 0x11aa */
+	0x3134,	    /* 0x11ab */
+	0x3135,	    /* 0x11ac */
+	0x3136,	    /* 0x11ad */
+	0x3137,	    /* 0x11ae */
+	0x3139,	    /* 0x11af */
+	0x313a,	    /* 0x11b0 */
+	0x313b,	    /* 0x11b1 */
+	0x313c,	    /* 0x11b2 */
+	0x313d,	    /* 0x11b3 */
+	0x313e,	    /* 0x11b4 */
+	0x313f,	    /* 0x11b5 */
+	0x3140,	    /* 0x11b6 */
+	0x3141,	    /* 0x11b7 */
+	0x3142,	    /* 0x11b8 */
+	0x3144,	    /* 0x11b9 */
+	0x3145,	    /* 0x11ba */
+	0x3146,	    /* 0x11bb */
+	0x3147,	    /* 0x11bc */
+	0x3148,	    /* 0x11bd */
+	0x314a,	    /* 0x11be */
+	0x314b,	    /* 0x11bf */
+	0x314c,	    /* 0x11c0 */
+	0x314d,	    /* 0x11c1 */
+	0x314e,	    /* 0x11c2 */
 	0x0000,     /* 0x11c3 */
 	0x0000,     /* 0x11c4 */
 	0x0000,     /* 0x11c5 */
