@@ -272,6 +272,11 @@ static const HangulKeyboard hangul_keyboard_romaja = {
     (ucschar*)hangul_keyboard_table_romaja
 };
 
+static const HangulKeyboard hangul_keyboard_an = {
+    HANGUL_KEYBOARD_TYPE_JASO,
+    (ucschar*)hangul_keyboard_table_an
+};
+
 static const HangulCombination hangul_combination_default = {
     N_ELEMENTS(hangul_combination_table_default),
     (HangulCombinationItem*)hangul_combination_table_default
@@ -287,6 +292,11 @@ static const HangulCombination hangul_combination_full = {
     (HangulCombinationItem*)hangul_combination_table_full
 };
 
+static const HangulCombination hangul_combination_an = {
+    N_ELEMENTS(hangul_combination_table_an),
+    (HangulCombinationItem*)hangul_combination_table_an
+};
+
 static void    hangul_buffer_push(HangulBuffer *buffer, ucschar ch);
 static ucschar hangul_buffer_pop (HangulBuffer *buffer);
 static ucschar hangul_buffer_peek(HangulBuffer *buffer);
@@ -1630,6 +1640,11 @@ hangul_ic_select_keyboard(HangulInputContext *hic, const char* id)
 	hic->combination = &hangul_combination_romaja;
 	hic->output_mode = HANGUL_OUTPUT_SYLLABLE;
 	hic->use_jamo_mode_only = FALSE;
+    } else if (strcmp(id, "an") == 0) {
+	hic->keyboard = &hangul_keyboard_an;
+	hic->combination = &hangul_combination_an;
+	hic->output_mode = HANGUL_OUTPUT_SYLLABLE;
+	hic->use_jamo_mode_only = FALSE;
     } else {
 	hic->keyboard = &hangul_keyboard_2;
 	hic->combination = &hangul_combination_default;
